@@ -163,7 +163,7 @@ def _create_deb_file(conanfile):
         conanfile.run("rm -rf " + deb_folder)
         output.info("clean deb_folder in package.")
     else:
-        msg = "deb_folde '%s' is not existed. \
+        msg = "deb_folder '%s' is not existed. \
                 Check deb_folder is generated correctly." % (deb_folder)
         output.warn(msg)       
 
